==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterClaimStatusBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterClaimStatusBuilder extends ClusterClaimStatusFluentImpl<ClusterClaimStatusBuilder> implements VisitableBuilder<ClusterClaimStatus,ClusterClaimStatusBuilder>{
  public ClusterClaimStatusBuilder() {
    this(false);
  }
  public ClusterClaimStatusBuilder(Boolean validationEnabled) {
    this(new ClusterClaimStatus(), validationEnabled);
  }
  public ClusterClaimStatusBuilder(ClusterClaimStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterClaimStatusBuilder(ClusterClaimStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterClaimStatus(), validationEnabled);
  }
  public ClusterClaimStatusBuilder(ClusterClaimStatusFluent<?> fluent,ClusterClaimStatus instance) {
    this(fluent, instance, false);
  }
  public ClusterClaimStatusBuilder(ClusterClaimStatusFluent<?> fluent,ClusterClaimStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withConditions(instance.getConditions());
      fluent.withLifetime(instance.getLifetime());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterClaimStatusBuilder(ClusterClaimStatus instance) {
    this(instance,false);
  }
  public ClusterClaimStatusBuilder(ClusterClaimStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withConditions(instance.getConditions());
      this.withLifetime(instance.getLifetime());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterClaimStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterClaimStatus build() {
    ClusterClaimStatus buildable = new ClusterClaimStatus(fluent.getConditions(),fluent.getLifetime());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterClaimStatusBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterClaimStatusBuilder extends ClusterClaimStatusFluent<ClusterClaimStatusBuilder> implements VisitableBuilder<ClusterClaimStatus,ClusterClaimStatusBuilder>{
  public ClusterClaimStatusBuilder() {
    this(false);
  }
  public ClusterClaimStatusBuilder(Boolean validationEnabled) {
    this(new ClusterClaimStatus(), validationEnabled);
  }
  public ClusterClaimStatusBuilder(ClusterClaimStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterClaimStatusBuilder(ClusterClaimStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterClaimStatus(), validationEnabled);
  }
  public ClusterClaimStatusBuilder(ClusterClaimStatusFluent<?> fluent,ClusterClaimStatus instance) {
    this(fluent, instance, false);
  }
  public ClusterClaimStatusBuilder(ClusterClaimStatusFluent<?> fluent,ClusterClaimStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ClusterClaimStatus());

    if (instance != null) {
      fluent.withConditions(instance.getConditions());
      fluent.withLifetime(instance.getLifetime());
      fluent.withConditions(instance.getConditions());
      fluent.withLifetime(instance.getLifetime());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterClaimStatusBuilder(ClusterClaimStatus instance) {
    this(instance,false);
  }
  public ClusterClaimStatusBuilder(ClusterClaimStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ClusterClaimStatus());

    if (instance != null) {
      this.withConditions(instance.getConditions());
      this.withLifetime(instance.getLifetime());
      this.withConditions(instance.getConditions());
      this.withLifetime(instance.getLifetime());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterClaimStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterClaimStatus build() {
    ClusterClaimStatus buildable = new ClusterClaimStatus(fluent.buildConditions(),fluent.getLifetime());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
